Skip to contents

Loads light data from specified file paths. Will handle different file formats based on file extensions.

Usage

get_light_data(filepaths)

Arguments

filepaths

A vector of file paths to logger data files.

Value

A data frame containing the loaded light data.