Create Filter Settings File
create_filter_settings_file.RdCreate an example filter settings Excel file for specified species.
The file will contain default filter settings for each species.
See read_filter_file for reading the filter file.
Usage
create_filter_settings_file(filepath, species = c())