Remove twilights that form subsequent outliers in time of noon and midnight.
noonfilter.RdThis function performs the following steps:
Calculate noon/midnight based on twilight.
make noon/midnight circular.
split data set into day and night
loess predictions of noon/midnight (after excluding twilights with extreme variation from predictions)
fill data gaps in predictions with baytrends::fillMissing()
find the minimum difference between a noon/midnight directly calculated from twilights and any predicted noon/midnight 4 days ahead or after candidate noon/midnight.
threshold for removing twilight is when difference between noon/midnight vs prediction overreach 0.4h, but under under 12h